==> tensorflow_federated_nightly-0.17.0.dev20210123-py2.py3-none-any.whl: tensorflow_federated/python/aggregators/__init__.py <==
# Copyright 2020, The TensorFlow Federated Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Libraries for constructing federated aggregation."""

from tensorflow_federated.python.aggregators.dp_factory import DifferentiallyPrivateFactory
from tensorflow_federated.python.aggregators.encoded_factory import EncodedSumFactory
from tensorflow_federated.python.aggregators.factory import UnweightedAggregationFactory
from tensorflow_federated.python.aggregators.factory import WeightedAggregationFactory
from tensorflow_federated.python.aggregators.mean_factory import MeanFactory
from tensorflow_federated.python.aggregators.mean_factory import UnweightedMeanFactory
from tensorflow_federated.python.aggregators.quantile_estimation import PrivateQuantileEstimationProcess
from tensorflow_federated.python.aggregators.robust_factory import clipping_factory
from tensorflow_federated.python.aggregators.robust_factory import zeroing_factory
from tensorflow_federated.python.aggregators.secure_factory import SecureSumFactory
from tensorflow_federated.python.aggregators.sum_factory import SumFactory

==> tensorflow_federated_nightly-0.18.0.dev20210207-py2.py3-none-any.whl: tensorflow_federated/python/aggregators/__init__.py <==
# Copyright 2020, The TensorFlow Federated Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Libraries for constructing federated aggregation.

For example uses of the symbols in this module, see
[Tuning recommended aggregations for learning](
https://www.tensorflow.org/federated/tutorials/tuning_recommended_aggregators)
tutorial, and for details of the design and how to implement new aggregations,
see [Implementing Custom Aggregations](
https://www.tensorflow.org/federated/tutorials/custom_aggregators) tutorial.
"""

from tensorflow_federated.python.aggregators.dp_factory import DifferentiallyPrivateFactory
from tensorflow_federated.python.aggregators.encoded_factory import EncodedSumFactory
from tensorflow_federated.python.aggregators.factory import UnweightedAggregationFactory
from tensorflow_federated.python.aggregators.factory import WeightedAggregationFactory
from tensorflow_federated.python.aggregators.mean_factory import MeanFactory
from tensorflow_federated.python.aggregators.mean_factory import UnweightedMeanFactory
from tensorflow_federated.python.aggregators.quantile_estimation import PrivateQuantileEstimationProcess
from tensorflow_federated.python.aggregators.robust_factory import clipping_factory
from tensorflow_federated.python.aggregators.robust_factory import zeroing_factory
from tensorflow_federated.python.aggregators.secure_factory import SecureSumFactory
from tensorflow_federated.python.aggregators.sum_factory import SumFactory
